package androidx.test.espresso.action;

import android.view.View;
import android.widget.Adapter;
import android.widget.AdapterView;
import androidx.test.espresso.PerformException;
import androidx.test.espresso.UiController;
import androidx.test.espresso.ViewAction;
import androidx.test.espresso.action.AdapterViewProtocol;
import androidx.test.espresso.core.internal.deps.guava.base.Preconditions;
import androidx.test.espresso.core.internal.deps.guava.collect.Lists;
import androidx.test.espresso.matcher.ViewMatchers;
import androidx.test.espresso.util.EspressoOptional;
import androidx.test.espresso.util.HumanReadables;
import java.util.ArrayList;
import java.util.Locale;
import org.hamcrest.Matcher;
import org.hamcrest.Matchers;
import org.hamcrest.StringDescription;
/* loaded from: classes3.dex */
public final class AdapterDataLoaderAction implements ViewAction {
    private AdapterViewProtocol.AdaptedData adaptedData;
    final AdapterViewProtocol adapterViewProtocol;
    final EspressoOptional<Integer> atPosition;
    final Matcher<? extends Object> dataToLoadMatcher;
    private boolean performed = false;
    private final Object dataLock = new Object();

    @Override // androidx.test.espresso.ViewAction
    public String getDescription() {
        return "load adapter data";
    }

    public AdapterDataLoaderAction(Matcher<? extends Object> dataToLoadMatcher, EspressoOptional<Integer> atPosition, AdapterViewProtocol adapterViewProtocol) {
        this.dataToLoadMatcher = (Matcher) Preconditions.checkNotNull(dataToLoadMatcher);
        this.atPosition = (EspressoOptional) Preconditions.checkNotNull(atPosition);
        this.adapterViewProtocol = (AdapterViewProtocol) Preconditions.checkNotNull(adapterViewProtocol);
    }

    public AdapterViewProtocol.AdaptedData getAdaptedData() {
        AdapterViewProtocol.AdaptedData adaptedData;
        synchronized (this.dataLock) {
            Preconditions.checkState(this.performed, "perform hasn't beenViewFinderImpl called yet!");
            adaptedData = this.adaptedData;
        }
        return adaptedData;
    }

    @Override // androidx.test.espresso.ViewAction
    public Matcher<View> getConstraints() {
        return Matchers.allOf(ViewMatchers.isAssignableFrom(AdapterView.class), ViewMatchers.isDisplayed());
    }

    @Override // androidx.test.espresso.ViewAction
    public void perform(UiController uiController, View view) {
        int i;
        AdapterView<? extends Adapter> adapterView = (AdapterView) view;
        ArrayList newArrayList = Lists.newArrayList();
        for (AdapterViewProtocol.AdaptedData adaptedData : this.adapterViewProtocol.getDataInAdapterView(adapterView)) {
            if (this.dataToLoadMatcher.matches(adaptedData.getData())) {
                newArrayList.add(adaptedData);
            }
        }
        if (newArrayList.size() == 0) {
            StringDescription stringDescription = new StringDescription();
            this.dataToLoadMatcher.describeTo(stringDescription);
            if (newArrayList.isEmpty()) {
                stringDescription.appendText(" contained values: ");
                stringDescription.appendValue(this.adapterViewProtocol.getDataInAdapterView(adapterView));
                PerformException.Builder withViewDescription = new PerformException.Builder().withActionDescription(getDescription()).withViewDescription(HumanReadables.describe(view));
                String valueOf = String.valueOf(stringDescription);
                StringBuilder sb = new StringBuilder(String.valueOf(valueOf).length() + 24);
                sb.append("No data found matching: ");
                sb.append(valueOf);
                throw withViewDescription.withCause(new RuntimeException(sb.toString())).build();
            }
        }
        synchronized (this.dataLock) {
            i = 0;
            Preconditions.checkState(!this.performed, "perform called 2x!");
            this.performed = true;
            if (this.atPosition.isPresent()) {
                int size = newArrayList.size() - 1;
                if (this.atPosition.get().intValue() > size) {
                    throw new PerformException.Builder().withActionDescription(getDescription()).withViewDescription(HumanReadables.describe(view)).withCause(new RuntimeException(String.format(Locale.ROOT, "There are only %d elements that matched but requested %d element.", Integer.valueOf(size), this.atPosition.get()))).build();
                }
                this.adaptedData = (AdapterViewProtocol.AdaptedData) newArrayList.get(this.atPosition.get().intValue());
            } else if (newArrayList.size() != 1) {
                StringDescription stringDescription2 = new StringDescription();
                this.dataToLoadMatcher.describeTo(stringDescription2);
                PerformException.Builder withViewDescription2 = new PerformException.Builder().withActionDescription(getDescription()).withViewDescription(HumanReadables.describe(view));
                String valueOf2 = String.valueOf(stringDescription2);
                String valueOf3 = String.valueOf(newArrayList);
                StringBuilder sb2 = new StringBuilder(String.valueOf(valueOf2).length() + 44 + String.valueOf(valueOf3).length());
                sb2.append("Multiple data elements matched: ");
                sb2.append(valueOf2);
                sb2.append(". Elements: ");
                sb2.append(valueOf3);
                throw withViewDescription2.withCause(new RuntimeException(sb2.toString())).build();
            } else {
                this.adaptedData = (AdapterViewProtocol.AdaptedData) newArrayList.get(0);
            }
        }
        while (!this.adapterViewProtocol.isDataRenderedWithinAdapterView(adapterView, this.adaptedData)) {
            if (i > 1) {
                if (i % 50 == 0) {
                    adapterView.invalidate();
                    this.adapterViewProtocol.makeDataRenderedWithinAdapterView(adapterView, this.adaptedData);
                }
            } else {
                this.adapterViewProtocol.makeDataRenderedWithinAdapterView(adapterView, this.adaptedData);
            }
            uiController.loopMainThreadForAtLeast(100L);
            i++;
        }
    }
}
