package androidx.test.espresso.matcher;

import android.app.Activity;
import android.os.Build;
import android.os.IBinder;
import android.util.Log;
import android.view.View;
import androidx.test.espresso.Root;
import androidx.test.espresso.core.internal.deps.guava.base.Preconditions;
import androidx.test.espresso.core.internal.deps.guava.collect.Lists;
import androidx.test.espresso.remote.annotation.RemoteMsgConstructor;
import androidx.test.espresso.remote.annotation.RemoteMsgField;
import androidx.test.runner.lifecycle.ActivityLifecycleMonitorRegistry;
import androidx.test.runner.lifecycle.Stage;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import org.hamcrest.Description;
import org.hamcrest.Matcher;
import org.hamcrest.Matchers;
import org.hamcrest.TypeSafeMatcher;
/* loaded from: classes2.dex */
public final class RootMatchers {
    public static final Matcher<Root> DEFAULT = Matchers.allOf(hasWindowLayoutParams(), Matchers.allOf(Matchers.anyOf(Matchers.allOf(isDialog(), withDecorView(hasWindowFocus())), isSubwindowOfCurrentActivity()), isFocusable()));
    private static final String TAG = "RootMatchers";

    private RootMatchers() {
    }

    public static Matcher<Root> isFocusable() {
        return new IsFocusable();
    }

    public static Matcher<Root> isTouchable() {
        return new IsTouchable();
    }

    public static Matcher<Root> isDialog() {
        return new IsDialog();
    }

    public static Matcher<Root> isSystemAlertWindow() {
        return new IsSystemAlertWindow();
    }

    public static Matcher<Root> isPlatformPopup() {
        return new IsPlatformPopup();
    }

    public static Matcher<Root> withDecorView(final Matcher<View> decorViewMatcher) {
        Preconditions.checkNotNull(decorViewMatcher);
        return new WithDecorView(decorViewMatcher);
    }

    private static Matcher<View> hasWindowFocus() {
        return new HasWindowFocus();
    }

    public static Matcher<Root> hasWindowLayoutParams() {
        return new HasWindowLayoutParams();
    }

    private static Matcher<Root> isSubwindowOfCurrentActivity() {
        return new IsSubwindowOfCurrentActivity();
    }

    /* JADX INFO: Access modifiers changed from: private */
    public static List<IBinder> getResumedActivityTokens() {
        Collection<Activity> activitiesInStage = ActivityLifecycleMonitorRegistry.getInstance().getActivitiesInStage(Stage.RESUMED);
        if (activitiesInStage.isEmpty()) {
            Log.w(TAG, "suppressed: NoActivityResumedException(\"At least one activity should be in RESUMED stage.\"");
        }
        ArrayList newArrayList = Lists.newArrayList();
        for (Activity activity : activitiesInStage) {
            newArrayList.add(activity.getWindow().getDecorView().getApplicationWindowToken());
        }
        return newArrayList;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    /* loaded from: classes4.dex */
    public static final class IsFocusable extends TypeSafeMatcher<Root> {
        @Override // org.hamcrest.SelfDescribing
        public void describeTo(Description description) {
            description.appendText("is focusable");
        }

        @Override // org.hamcrest.TypeSafeMatcher
        public boolean matchesSafely(Root root) {
            return (root.getWindowLayoutParams().get().flags & 8) != 8;
        }
    }

    /* loaded from: classes4.dex */
    static final class IsTouchable extends TypeSafeMatcher<Root> {
        @Override // org.hamcrest.SelfDescribing
        public void describeTo(Description description) {
            description.appendText("is touchable");
        }

        @Override // org.hamcrest.TypeSafeMatcher
        public boolean matchesSafely(Root root) {
            return (root.getWindowLayoutParams().get().flags & 16) != 16;
        }
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    /* loaded from: classes4.dex */
    public static final class IsDialog extends TypeSafeMatcher<Root> {
        @Override // org.hamcrest.SelfDescribing
        public void describeTo(Description description) {
            description.appendText("is dialog");
        }

        @Override // org.hamcrest.TypeSafeMatcher
        public boolean matchesSafely(Root root) {
            int i = root.getWindowLayoutParams().get().type;
            return i != 1 && i < 99 && root.getDecorView().getWindowToken() == root.getDecorView().getApplicationWindowToken();
        }
    }

    /* loaded from: classes4.dex */
    static final class IsSystemAlertWindow extends TypeSafeMatcher<Root> {
        @Override // org.hamcrest.SelfDescribing
        public void describeTo(Description description) {
            description.appendText("is system alert window");
        }

        @Override // org.hamcrest.TypeSafeMatcher
        public boolean matchesSafely(Root root) {
            int i = root.getWindowLayoutParams().get().type;
            return 2000 < i && 2999 > i && root.getDecorView().getWindowToken() == root.getDecorView().getApplicationWindowToken();
        }
    }

    /* loaded from: classes4.dex */
    static final class IsPlatformPopup extends TypeSafeMatcher<Root> {
        @Override // org.hamcrest.TypeSafeMatcher
        public boolean matchesSafely(Root item) {
            return RootMatchers.withDecorView(ViewMatchers.withClassName(Matchers.is(Build.VERSION.SDK_INT >= 23 ? "android.widget.PopupWindow$PopupDecorView" : "android.widget.PopupWindow$PopupViewContainer"))).matches(item);
        }

        @Override // org.hamcrest.SelfDescribing
        public void describeTo(Description description) {
            description.appendText("with decor view of type PopupWindow$PopupViewContainer");
        }
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    /* loaded from: classes4.dex */
    public static final class WithDecorView extends TypeSafeMatcher<Root> {
        @RemoteMsgField(order = 0)
        private final Matcher<View> decorViewMatcher;

        @RemoteMsgConstructor
        public WithDecorView(final Matcher<View> decorViewMatcher) {
            this.decorViewMatcher = decorViewMatcher;
        }

        @Override // org.hamcrest.SelfDescribing
        public void describeTo(Description description) {
            description.appendText("with decor view ");
            this.decorViewMatcher.describeTo(description);
        }

        @Override // org.hamcrest.TypeSafeMatcher
        public boolean matchesSafely(Root root) {
            return this.decorViewMatcher.matches(root.getDecorView());
        }
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    /* loaded from: classes4.dex */
    public static final class HasWindowFocus extends TypeSafeMatcher<View> {
        @Override // org.hamcrest.SelfDescribing
        public void describeTo(Description description) {
            description.appendText("has window focus");
        }

        @Override // org.hamcrest.TypeSafeMatcher
        public boolean matchesSafely(View view) {
            return view.hasWindowFocus();
        }
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    /* loaded from: classes4.dex */
    public static final class HasWindowLayoutParams extends TypeSafeMatcher<Root> {
        @Override // org.hamcrest.SelfDescribing
        public void describeTo(Description description) {
            description.appendText("has window layout params");
        }

        @Override // org.hamcrest.TypeSafeMatcher
        public boolean matchesSafely(Root root) {
            return root.getWindowLayoutParams().isPresent();
        }
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    /* loaded from: classes4.dex */
    public static final class IsSubwindowOfCurrentActivity extends TypeSafeMatcher<Root> {
        @Override // org.hamcrest.SelfDescribing
        public void describeTo(Description description) {
            description.appendText("is subwindow of current activity");
        }

        @Override // org.hamcrest.TypeSafeMatcher
        public boolean matchesSafely(Root root) {
            return RootMatchers.getResumedActivityTokens().contains(root.getDecorView().getApplicationWindowToken());
        }
    }
}
